Fix sample 11_texture_driver for hip-clang (#1370)
[ROCm/clr commit: 793b18c0b1]
This commit is contained in:
committed by
Maneesh Gupta
parent
0a81b64a19
commit
e5a61a51de
@@ -21,7 +21,12 @@ THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include "hip/hip_runtime.h"
|
||||
extern texture<float, 2, hipReadModeElementType> tex;
|
||||
#if __HIP__
|
||||
__hip_pinned_shadow__
|
||||
#else
|
||||
extern
|
||||
#endif
|
||||
texture<float, 2, hipReadModeElementType> tex;
|
||||
|
||||
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
|
||||
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
|
||||
|
||||
Reference in New Issue
Block a user